fs-attestation-safe-eth-py
###########################################

.. class:: no-web no-pdf

fs-attestation-safe-eth-py provides the SafeBaseAPI class in safe-eth-py library with the ability to accept a custom base url for the Safe Transaction Service:
  - The modified safe-cli (fs-attestation-safe-cli, available here https://pypi.org/project/fs-attestation-safe-cli/1.0.1/) uses this library to connect to a custom safe transaction service url

Quick start
-----------

Just run ``pip install fs-attestation-safe-eth-py`` or add it to your **requirements.txt**

Contributors
------------
- Mohan, Lead Blockchain Engineer, FailSafe, mohan@ethlas.com

- `See more about FailSafe <https://getfailsafe.com/>`_